@@ -95,8 +95,24 @@ class Corpus:
         return self.docs.__len__()
 
 class CorpusFromFile(Corpus):
-    def __init__(self, file):
-        self.docs = open(file, encoding='utf-8').readlines()
+    def __init__(self, file, encoding='utf-8'):
+        import re
+        emoji_pattern = re.compile("["
+                                   u"\U00010000-\U0010FFFF"
+                                   "]+", flags=re.UNICODE)
+        array = []
+        line_number = 0
+        with open(file, encoding=encoding) as original:
+            for line in original.readlines():
+                line_number += 1
+                try:
+                    after = emoji_pattern.sub(r'', line)
+                    array.append(after)
+                except IndexError:
+                    print('line number', line_number, 'txt 파일에서 확인요망')
+                    array.append()
+        self.docs = array
+
 
 class CorpusFromEojiFile(Corpus):
     def __init__(self, file):
