@@ -609,8 +609,8 @@ class pyTextMinerTopicModel:
         g.show_buttons()
         g.show(topic_network_result)
 
-    def lda_model(self, text_data, save_path, topic_number=20):
-        mdl = tp.LDAModel(tw=tp.TermWeight.ONE, min_cf=3, rm_top=5, k=topic_number)
+    def lda_model(self, text_data, save_path, topic_number=20, min_cf=3, rm_top=5, iteration=1500):
+        mdl = tp.LDAModel(tw=tp.TermWeight.ONE, min_cf=min_cf, rm_top=rm_top, k=topic_number)
         index=0
         for doc in text_data:
             print(str(index) + " : " + str(doc))
@@ -623,7 +623,7 @@ class pyTextMinerTopicModel:
         print('Num docs:', len(mdl.docs), ', Vocab size:', mdl.num_vocabs, ', Num words:', mdl.num_words)
         print('Removed top words:', mdl.removed_top_words)
         print('Training...', file=sys.stderr, flush=True)
-        for i in range(0, 1500, 10):
+        for i in range(0, iteration, 10):
             mdl.train(10)
             print('Iteration: {}\tLog-likelihood: {}'.format(i, mdl.ll_per_word))
 
@@ -645,22 +645,20 @@ class pyTextMinerTopicModel:
 
         return mdl
 
-    def dmr_model(self, text_data, pair_map, save_path, topic_number=20):
-        mdl = tp.DMRModel(tw=tp.TermWeight.ONE, min_cf=3, rm_top=5, k=topic_number)
+    def dmr_model(self, text_data, pair_map, save_path, topic_number=20, min_cf=3, rm_top=5, iteration=1500):
+        mdl = tp.DMRModel(tw=tp.TermWeight.ONE, min_cf=min_cf, rm_top=rm_top, k=topic_number)
 
-        index=0
-        for doc in text_data:
+        for index, doc in enumerate(text_data):
             print(str(index) + " : " + str(doc))
             year=pair_map[index]
             mdl.add_doc(doc,metadata=year)
-            index+=1
 
         mdl.burn_in = 100
         mdl.train(0)
         print('Num docs:', len(mdl.docs), ', Vocab size:', mdl.num_vocabs, ', Num words:', mdl.num_words)
         print('Removed top words:', mdl.removed_top_words)
         print('Training...', file=sys.stderr, flush=True)
-        for i in range(0, 1000, 10):
+        for i in range(0, iteration, 10):
             mdl.train(10)
             print('Iteration: {}\tLog-likelihood: {}'.format(i, mdl.ll_per_word))
 
